# ProductCategory

Category of the product. Used by Zuora Quotes Guided Product Selector.  Possible values are:   - Base Products   - Add On Services   - Miscellaneous Products 

## Enum

* `BASE_PRODUCTS` (value: `'Base Products'`)

* `ADD_ON_SERVICES` (value: `'Add On Services'`)

* `MISCELLANEOUS_PRODUCTS` (value: `'Miscellaneous Products'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


